/**
 * DevExtreme (esm/ui/date_range_box/ui.multiselect_date_box.js)
 * Version: 23.1.2
 * Build date: Wed May 17 2023
 *
 * Copyright (c) 2012 - 2023 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import $ from "../../core/renderer";
import DateBox from "../date_box/ui.date_box.mask";
import RangeCalendarStrategy from "./strategy/rangeCalendar";
class MultiselectDateBox extends DateBox {
    _initStrategy() {
        this._strategy = new RangeCalendarStrategy(this)
    }
    _applyButtonHandler(_ref) {
        var {
            event: event
        } = _ref;
        var value = this._strategy.getValue();
        this._strategy.dateRangeBox.updateValue(value, event);
        this.close();
        this.option("focusStateEnabled") && this.focus()
    }
    _openHandler(e) {
        if (this._strategy.dateRangeBox.option("opened")) {
            return
        }
        super._openHandler(e)
    }
    _renderOpenedState() {
        var _this$_strategy$dateR, _this$_strategy$dateR2;
        var opened = null !== (_this$_strategy$dateR = null === (_this$_strategy$dateR2 = this._strategy.dateRangeBox.getStartDateBox()) || void 0 === _this$_strategy$dateR2 ? void 0 : _this$_strategy$dateR2.option("opened")) && void 0 !== _this$_strategy$dateR ? _this$_strategy$dateR : this.option("opened");
        this._strategy.dateRangeBox._toggleDropDownEditorActiveClass(opened);
        super._renderOpenedState()
    }
    _popupShownHandler() {
        var _this$_strategy$dateR3;
        super._popupShownHandler();
        null === (_this$_strategy$dateR3 = this._strategy.dateRangeBox._validationMessage) || void 0 === _this$_strategy$dateR3 ? void 0 : _this$_strategy$dateR3.option("positionSide", this._getValidationMessagePositionSide())
    }
    _popupHiddenHandler() {
        var _this$_strategy$dateR4;
        super._popupHiddenHandler();
        null === (_this$_strategy$dateR4 = this._strategy.dateRangeBox._validationMessage) || void 0 === _this$_strategy$dateR4 ? void 0 : _this$_strategy$dateR4.option("positionSide", this._getValidationMessagePositionSide())
    }
    _closeOutsideDropDownHandler(e) {
        var {
            target: target
        } = e;
        var [startDateInput, endDateInput] = this._strategy.dateRangeBox.field();
        return super._closeOutsideDropDownHandler(e) && !($(target).is(startDateInput) || $(target).is(endDateInput))
    }
    _focusInHandler(e) {
        super._focusInHandler(e);
        var {
            target: target
        } = e;
        var [startDateInput, endDateInput] = this._strategy.dateRangeBox.field();
        if ($(target).is(startDateInput)) {
            this._strategy.dateRangeBox.option("_currentSelection", "startDate")
        }
        if ($(target).is(endDateInput)) {
            this._strategy.dateRangeBox.option("_currentSelection", "endDate")
        }
        if (!this._strategy.dateRangeBox.getStartDateBox()._strategy._widget) {
            return
        }
        var value = this._strategy.dateRangeBox.getStartDateBox()._strategy._widget.option("values");
        if ($(target).is(startDateInput)) {
            this._strategy.setActiveStartDateBox();
            this._strategy._widget.option("_currentSelection", "startDate");
            this._strategy._widget._setViewsMaxOption(value[1])
        }
        if ($(target).is(endDateInput)) {
            this._strategy.dateRangeBox.getStartDateBox()._strategy.setActiveEndDateBox();
            this._strategy.dateRangeBox.getStartDateBox()._strategy._widget.option("_currentSelection", "endDate");
            this._strategy.dateRangeBox.getStartDateBox()._strategy._widget._setViewsMinOption(value[0])
        }
    }
    _updateInternalValidationState(isValid, validationMessage) {
        this.option({
            isValid: isValid,
            validationError: isValid ? null : {
                message: validationMessage
            }
        })
    }
    _recallInternalValidation(value) {
        this._applyInternalValidation(value)
    }
    _isTargetOutOfComponent(target) {
        var $dateRangeBox = this._strategy.dateRangeBox.$element();
        var isTargetOutOfDateRangeBox = 0 === $(target).closest($dateRangeBox).length;
        return super._isTargetOutOfComponent(target) && isTargetOutOfDateRangeBox
    }
    _optionChanged(args) {
        switch (args.name) {
            case "isValid":
                var isValid = this._strategy.dateRangeBox.option("isValid");
                if (this._skipIsValidOptionChange || isValid === args.value) {
                    super._optionChanged(args);
                    return
                }
                this._skipIsValidOptionChange = true;
                this.option({
                    isValid: isValid
                });
                this._skipIsValidOptionChange = false;
                break;
            default:
                super._optionChanged(args)
        }
    }
}
export default MultiselectDateBox;
